@@ -1,7 +1,7 @@
 from .abstraction import Statuses, ToCompare
+from .compare_base import Compare
+from .compare_combined import CompareCombined
 from .config import Config
-from .parameter_base import Compare
-from .parameter_combined import CompareCombined
 from .property import Property
 
 __all__ = ["Statuses", "ToCompare", "Compare", "CompareCombined", "Property", "Config"]
